OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighet %s)",
    "You attended a call with {user1}" : "Du har tatt del i en samtale med {user1}",
    "_%n guest_::_%n guests_" : ["%n gjest","%n gjester"],
    "You attended a call with {user1} and {user2}" : "Du har tatt del i en samtale med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du har tatt del i en samtale med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["én annen person","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>, eller fikk et <strong>anrop</strong>",
    "Other activities" : "Andre aktiviteter",
    "Talk" : "Samtale",
    "Guest" : "Gjest",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtalen vil vi informere deg om Nextcloud Talks nye funksjoner.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nå bli benyttet for å delta i lyd- og videosamtaler",
    "- You can now mention guests in the chat" : "- Du kan nå nevne gjester i chat'n",
    "Talk updates ✅" : "Talk oppdateringer ✅",
    "{actor} created the conversation" : "{actor} opprettet samtalen",
    "You created the conversation" : "Du opprettet samtalen",
    "An administrator created the conversation" : "En administrator opprettet samtalen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} endret navnet på samtalen fra  \"%1$s\" til \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du endret navnet på samtalen fra \"%1$s\" til \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administrator endret navnet på samtalen fra \"%1$s\" til \"%2$s\"",
    "{actor} removed the description" : "{actor} fjernet beskrivelsen",
    "You removed the description" : "Du fjernet beskrivelsen",
    "An administrator removed the description" : "En administrator fjernet beskrivelsen",
    "{actor} started a call" : "{actor} startet en samtale",
    "You started a call" : "Du startet et anrop",
    "{actor} joined the call" : "{actor} ble med i samtalen",
    "You joined the call" : "Du ble med i samtalen",
    "{actor} left the call" : "{actor} forlot samtalen",
    "You left the call" : "Du forlot samtalen",
    "{actor} unlocked the conversation" : "{actor} låste opp samtalen",
    "You unlocked the conversation" : "Du låste opp samtalen",
    "An administrator unlocked the conversation" : "En administrator låste opp samtalen",
    "{actor} locked the conversation" : "{actor} låste samtalen",
    "You locked the conversation" : "Du låste samtalen",
    "An administrator locked the conversation" : "En administrator låste samtalen",
    "The conversation is now open to everyone" : "Samtalen er nå åpen for alle",
    "{actor} opened the conversation to everyone" : "{actor} åpnet samtalen for alle",
    "You opened the conversation to everyone" : "Du åpnet samtalen for alle",
    "{actor} allowed guests" : "{actor} tillot gjester",
    "You allowed guests" : "Du tillot gjester",
    "An administrator allowed guests" : "En administrator tillot gjester",
    "{actor} set a password" : "{actor} satte et passord",
    "You set a password" : "Du satte et passord",
    "An administrator set a password" : "En administrator satte et passord",
    "{actor} removed the password" : "{actor} fjernet passordet",
    "You removed the password" : "Du fjernet passordet",
    "An administrator removed the password" : "En administrator fjernet passordet",
    "{actor} added {user}" : "{actor} delte med {user}",
    "You added {user}" : "Du delte med {user}",
    "{actor} added you" : "{actor} la til deg",
    "An administrator added you" : "En administrator la til deg",
    "An administrator added {user}" : "En administrator delte med {user}",
    "You left the conversation" : "Du forlot samtalen",
    "{actor} left the conversation" : "{actor} forlot samtalen",
    "{actor} removed {user}" : "{actor} fjernet {user}",
    "You removed {user}" : "Du fjernet {user}",
    "{actor} removed you" : "{actor} fjernet deg",
    "An administrator removed you" : "En administrator fjernet deg",
    "An administrator removed {user}" : "En administrator fjernet {user}",
    "{actor} promoted {user} to moderator" : "{actor} forfremmet {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmet {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmet deg til moderator",
    "An administrator promoted you to moderator" : "En administrator forfremmet deg til moderator",
    "An administrator promoted {user} to moderator" : "En administrator forfremmet {user} til moderator",
    "You shared a file which is no longer available" : "Du delte en fil som ikke lenger er tilgjengelig",
    "%s (guest)" : "%s (gjest)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtale med %n gjest (Varighet {duration})","Samtale med %n gjester (Varighet {duration})"],
    "Talk conversations" : "Talk-samtaler",
    "Talk to %s" : "Snakk med %s",
    "File is too big" : "Filen er for stor",
    "Invalid file provided" : "Ugyldig fil oppgitt",
    "Invalid image" : "Ugyldig bilde",
    "Unknown filetype" : "Ukjent filtype",
    "Talk mentions" : "Talk nevner",
    "Write to conversation" : "Skrive til samtalen",
    "You were invited to a conversation." : "Du ble invitert til en samtale.",
    "Conversation invitation" : "Samtale invitasjon",
    "Click the button below to join." : "Klikk på knappen nedenfor for å delta.",
    "Join »%s«" : "Bli med »%s«",
    "You can also dial-in via phone with the following details" : "Du kan også ringe via telefon med følgende detaljer",
    "Dial-in information" : "Ringe informasjon",
    "Meeting ID" : "Møte ID",
    "Your PIN" : "Din PIN",
    "Private conversation" : "Privat samtale",
    "Deleted user (%s)" : "Slettet bruker (%s)",
    "Dismiss notification" : "Ingen varsel",
    "{user} in {call}" : "{user} i {call}",
    "Deleted user in {call}" : "Slett bruker i {call}",
    "{guest} (guest) in {call}" : "{guest} (gjest) i {call}",
    "Guest in {call}" : "Gjest i {call}",
    "{user} sent you a private message" : "{user} sente deg en privat melding",
    "{user} sent a message in conversation {call}" : "{user} sente en melding i samtalen {call}",
    "View chat" : "Vis samtale",
    "Join call" : "Ta del i samtale",
    "Answer call" : "Svar anrop",
    "Call back" : "Ring tilbake",
    "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
    "Open settings" : "Åpne innstillinger",
    "Conversations" : "Samtaler",
    "Messages" : "Meldinger",
    "{user}" : "{bruker}",
    "Messages in {conversation}" : "Meldinger i {conversation}",
    "{user} in {conversation}" : "{user} i {conversation}",
    "Messages in other conversations" : "Meldinger i andre samtaler",
    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
    "Something unexpected happened." : "Noe uventet inntraff.",
    "The URL is invalid." : "Nettadressen er ugyldig.",
    "An HTTPS URL is required." : "En HTTPS URL er påkrevd.",
    "The email address is invalid." : "Epostadressen er ugyldig.",
    "The language is invalid." : "Angitt språk er ugyldig.",
    "The country is invalid." : "Angitt land er ugyldig",
    "Something unexpected happened. Please try again later." : "Noe uventet inntraff. Vennligst prøv igjen senere.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De forente arabiske emirater",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua og Barbuda",
    "Anguilla" : "Angola",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikansk Samoa",
    "Austria" : "Østerike",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius og Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetøya",
    "Botswana" : "Botswana",
    "Belarus" : "Hviterusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosøyene",
    "Central African Republic" : "Den sentralafrikanske republikk",
    "Congo" : "Kongo",
    "Switzerland" : "Sveits",
    "Côte d'Ivoire" : "Elfenbenskysten",
    "Cook Islands" : "Cookøyene",
    "Chile" : "Chile",
    "Cameroon" : "Kameron",
    "China" : "Kina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapp Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmasøya",
    "Cyprus" : "Kypros",
    "Czechia" : "Tsjekkia",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Den dominikanske republikk",
    "Algeria" : "Algeri",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypt",
    "Western Sahara" : "Vest-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandsøyene (Malvinas)",
    "Faroe Islands" : "Færøyene",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Storbritannia og Nord-Irland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Fransk Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grønland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorial-Guinea",
    "Greece" : "Hellas",
    "South Georgia and the South Sandwich Islands" : "Sør-Georgia og Sør-Sandwichøyene",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard- og McDonaldøyene",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Det britiske territoriet i Indiahavet",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komorene",
    "Saint Kitts and Nevis" : "Saint Kitts og Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (Fransk del)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshalløyene",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Nord-Marianene",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldivene",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Ny-Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkøya",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransk Polynesia",
    "Papua New Guinea" : "Papua Ny-Guinea",
    "Philippines" : "Filipinene",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre og Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Russland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Seychelles" : "Seychellene ",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sør Sudan",
    "Sao Tome and Principe" : "Sao Tome og Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Nederlandsk del)",
    "Syrian Arab Republic" : "Syria",
    "Turks and Caicos Islands" : "Turks- og Caicosøyene",
    "Chad" : "Chad",
    "French Southern Territories" : "De franske sørterritorier",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkia",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "USAs ytre småøyer",
    "United States of America" : "USA",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Den hellige stol",
    "Saint Vincent and the Grenadines" : "Saint Vincent og Grenadinene",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Jomfruøyene, engelsk",
    "Virgin Islands, U.S." : "Jomfruøyene, US",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis- og Futunaøyene",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sør-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Conversation not found" : "Samtalen ble ikke funnet",
    "Leave call" : "Forlat samtalen",
    "Stay in call" : "Forbli i samtalen",
    "Duplicate session" : "Dupliser økten",
    "Discuss this file" : "Diskuter denne filen",
    "Share this file with others to discuss it" : "Del denne filen med andre og diskuter den",
    "Share this file" : "Del denne filen",
    "Join conversation" : "Delta i samtale",
    "Request password" : "Forespør om passord",
    "This conversation has ended" : "Denne samtalen er avsluttet",
    "Limit to groups" : "Begrens til grupper",
    "Everyone" : "Alle",
    "Moderators only" : "Kun moderatorer",
    "Save changes" : "Lagre endringer",
    "Saving …" : "Lagrer...",
    "Saved!" : "Lagret!",
    "Commands" : "Kommandoer",
    "Beta" : "Beta",
    "Name" : "Navn",
    "Command" : "Kommando",
    "Script" : "Skript",
    "Response to" : "Svar til",
    "Enabled for" : "Aktivert for",
    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Kommandoer er en ny beta funksjon i Nextcloud Talk. De tillater deg å kjøre skript på din Nextcloud server. Du kan definere dem med ditt kommandolinje grensesnitt. F.eks. et kalkulatorskript kan bli funnet i vår {linkstart}dokumentasjon{linkend}.",
    "None" : "Ingen",
    "User" : "Bruker",
    "Disabled" : "Deaktivert",
    "Moderators" : "Moderatorer",
    "Users" : "Brukere",
    "General settings" : "Generelle innstillinger",
    "All messages" : "Alle meldinger",
    "Off" : "ett kvarter",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Opprettet den",
    "Expires at" : "Utløper",
    "Pending" : "Venter",
    "Error" : "Feil",
    "Blocked" : "Blokkert",
    "Active" : "Aktiv",
    "Expired" : "Utløpt",
    "_%n user_::_%n users_" : ["%n bruker","%n brukere"],
    "Installed version: {version}" : "Installert versjon: {version}",
    "Downloading …" : "Laster ned …",
    "Install Talk Matterbridge" : "Installer Talk Matterbridge",
    "Validate SSL certificate" : "Bekreft SSL-sertifikat",
    "Delete this server" : "Slett denne serveren",
    "Status: Checking connection" : "Status: Sjekker tilkobling",
    "Shared secret" : "Delt hemmelighet",
    "SIP configuration" : "SIP innstillinger",
    "Restrict SIP configuration" : "Begrens SIP innstillinger",
    "Enable SIP configuration" : "Aktiver SIP innstillinger",
    "Phone number (Country)" : "Telefonnumer (fast)",
    "STUN server URL" : "STUN server URL",
    "STUN servers" : "STUN-server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
    "TURN server URL" : "TURN server URL",
    "TURN server protocols" : "TURN-serverprotokoller",
    "Test this server" : "Test denne serveren",
    "OK" : "OK",
    "Checking …" : "Sjekker…",
    "Back" : "Tilbake",
    "Confirm" : "Bekreft",
    "Reset" : "Tilbakestill",
    "Cancel" : "Avbryt",
    "Post message" : "Send melding",
    "A participant raised their hand." : "En deltaker løftet hånden.",
    "Previous page of videos" : "Forrige side med videoer",
    "Next page of videos" : "Neste side med videoer",
    "Copy link" : "Kopier lenke",
    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
    "Mute audio" : "Slå av lyd",
    "Unmute audio" : "Slå på lyd",
    "Disable video" : "Skru av video",
    "Enable video" : "Skru på video",
    "You" : "Du",
    "Show screen" : "Vis skjerm",
    "Mute" : "Dempe",
    "Collapse" : "Skjul",
    "Expand" : "Ekspander",
    "Conversation messages" : "Samtale meldinger",
    "You need to be logged in to upload files" : "Du må være på logget for å laste opp filer",
    "Drop your files to upload" : "Dropp filer for å laste opp",
    "Favorite" : "Merk som favoritt",
    "Description" : "Beskrivelse",
    "Restricted" : "Begrenset",
    "Conversation settings" : "Samtale innstillinger",
    "Personal" : "Personlig",
    "Meeting" : "Møte",
    "Permissions" : "Rettigheter",
    "Leave conversation" : "Forlat samtale",
    "Delete conversation" : "Slett samtale",
    "Delete chat messages" : "Slett melding",
    "Do you really want to delete \"{displayName}\"?" : "Vil du virkelig slette \"{displayName}\"?",
    "Delete all chat messages" : "Slett alle meldinger",
    "Error while clearing chat history" : "Det oppsto en feil. Kan ikke slette meldingslogg",
    "Submit" : "Send inn",
    "Guest access" : "Gjestetilgang",
    "Password protection" : "Passordbeskyttelse",
    "Save password" : "Lagre passord",
    "Copy conversation link" : "Kopier samtale lenke",
    "Conversation password has been saved" : "Samtale passord er lagret",
    "Conversation password has been removed" : "Samtale passord er fjernet",
    "Invitations sent" : "Invitasjoner sendt",
    "Meeting start time" : "Møtets starttidspunkt",
    "Start time (optional)" : "Starttidspunkt (valgfri)",
    "Start time has been updated" : "Starttidspunkt har blitt oppdatert",
    "Lock conversation" : "Lås samtalen",
    "Save" : "Lagre",
    "Edit" : "Rediger",
    "More information" : "Mer informasjon",
    "Delete" : "Slett",
    "Talk conversation" : "Talk-samtale",
    "Password" : "Passord",
    "API token" : "API-symbol",
    "Login" : "Logg inn",
    "Nickname" : "Kallenavn",
    "Client ID" : "Klient-ID",
    "Notifications" : "Varsler",
    "Mark as read" : "Merk som lest",
    "Mark as unread" : "Merk som ulest",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "You: {lastMessage}" : "Du: {lastMessage}",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Conversation list" : "Samtaleliste",
    "Loading" : "Laster",
    "No search results" : "Ingen søkeresultater",
    "Groups" : "Grupper",
    "Circles" : "Sirkler",
    "Unread mentions" : "Uleste nevner",
    "Talk settings" : "Talk innstillinger",
    "Users, groups and circles" : "Brukere, grupper og sirkler",
    "Users and groups" : "Brukere og grupper",
    "Users and circles" : "Brukere og sirkler",
    "Groups and circles" : "Grupper og sirkler",
    "Other sources" : "Andre kilder",
    "Password protect" : "Passordbeskyttelse",
    "Creating your conversation" : "Opprett din samtale",
    "Create conversation" : "Opprett samtale",
    "Add participants" : "Legg til deltager",
    "Close" : "Lukk",
    "Search participants" : "Søk etter deltakere",
    "Conversation name" : "Samtalenavn",
    "Search …" : "Søk...",
    "You are currently waiting in the lobby" : "Du venter for øyeblikket i lobbyen",
    "No microphone available" : "Ingen mikrofon er tilgjengelig",
    "Select microphone" : "Velg mikrofon",
    "No camera available" : "Ingen kamera tilgjengelig",
    "Select camera" : "Velg kamera",
    "Devices" : "Enheter",
    "Done" : "Ferdig",
    "No audio" : "Ingen lyd",
    "No camera" : "Ikke noe kamera",
    "Blur" : "Uklar",
    "Upload" : "Last opp",
    "Files" : "Filer",
    "File to share" : "Fil for deling",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Unread messages" : "Uleste meldinger",
    "Sending message" : "Sender melding",
    "Message sent" : "Melding sendt",
    "Only normal chat messages can be deleted" : "Kun vanlige meldinger kan slettes",
    "Dismiss" : "Forkast",
    "Reply" : "Svar",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} i {board}",
    "Poll" : "Avstemning",
    "No messages" : "Ingen meldinger",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Add emoji" : "Legg til emoji",
    "Send message" : "Send melding",
    "Group" : "Gruppe",
    "Upload from device" : "Last opp fra enhet",
    "Create new poll" : "Opprett ny avstemning",
    "New file" : "Ny fil",
    "Blank" : "Blank",
    "Settings" : "Innstillinger",
    "Create poll" : "Opprett avstemning",
    "Send" : "Send",
    "Join" : "Bli med",
    "moderator" : "moderator",
    "guest" : "gjest",
    "Demote from moderator" : "Fjern moderatorstatus",
    "Promote to moderator" : "Gi moderatorstatus",
    "Remove participant" : "Fjern deltaker",
    "Add emails" : "Legg til e-post",
    "Integrations" : "Integreringer",
    "Searching …" : "Søker ...",
    "No results" : "Ingen resultater",
    "Search for more users" : "Søk etter flere brukere",
    "Add users, groups or circles" : "Legg til brukere, grupper eller sirkler",
    "Add users or groups" : "Legg til bruker eller gruppe",
    "Participants" : "Deltakere",
    "Search or add participants" : "Finn eller legg til deltakere",
    "An error occurred while adding the participants" : "Det oppsto en feil. Kan ikke legge til deltakerne",
    "Chat" : "Chat",
    "Details" : "Detaljer",
    "Projects" : "Prosjekter",
    "Show all files" : "Vis alle filer",
    "Search conversations or users" : "Søk etter samtaler eller brukere",
    "Privacy" : "Personvern",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Search" : "Søk",
    "Start call" : "Start samtale",
    "Open sidebar" : "Åpne sidepanel",
    "Open chat" : "Åpne Chat",
    "Show your screen" : "Vis din skjerm",
    "Stop screensharing" : "Stopp skjermdeling",
    "Screensharing options" : "Skjermdelingsvalg",
    "Enable screensharing" : "Skru på skjermdeling",
    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
    "Grid view" : "Rutenett-visning",
    "Raise hand" : "Løft hånden",
    "Lower hand" : "Senk hånden",
    "Start a conversation" : "Start en samtale",
    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
    "Media" : "Media",
    "Polls" : "Avstemninger",
    "Locations" : "Steder",
    "Audio" : "Lyd",
    "Other" : "Annet",
    "Do not disturb" : "Ikke forstyrr",
    "Away" : "Borte",
    "Error while sharing file" : "Feil under deling av fil",
    "Default" : "Standard",
    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
    "TURN server" : "TURN-server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-serveren fungerer som mellomserver for trafikk fra deltakere bak en brannmur.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "More actions" : "Flere handlinger",
    "No matches" : "Ingen treff",
    "Rename conversation" : "Endre navn på samtale"
},
"nplurals=2; plural=(n != 1);");
